pub struct DeferredReplayStore {
buffer: Option<BufferedReplayEntry>,
}Expand description
Replay store that defers persisting the proof until flush is called. Used at the token endpoint so that when we return UseDpopNonce we do not record the JTI, allowing the client to retry with the nonce without hitting replay.
Fields
buffer: Option<BufferedReplayEntry>Implementations